#!/bin/sh

set -e

cd CommandNotFound/db

# the commands-not-found data is currently extracted here
scp -r nusakan.canonical.com:~mvo/cnf-extractor/command-not-found-extractor/dists/ .
find dists/ -name "*.xz" -o -name "*.gz" | xargs rm -f

